==> moodle_1.3.1.orig.tar.gz: moodle/lang/fa/workshop.php <==
<?PHP // $Id: workshop.php,v 1.2 2004/05/19 05:11:47 moodler Exp $ 
      // workshop.php - created with Moodle 1.3 Beta + (2004051600)


$string['absent'] = 'Absent';
$string['accumulative'] = 'Accumulative';
$string['action'] = 'Action';
$string['addacomment'] = 'Add a Comment';
$string['afterdeadline'] = 'After Deadline: $a';
$string['agreetothisassessment'] = 'Agree to this Assessment';
$string['allgradeshaveamaximumof'] = 'All Grades have a Maximum of: $a';
$string['allowresubmit'] = 'Allow Resubmissions';
$string['alreadyinphase'] = 'Already in Phase $a';
$string['amendassessmentelements'] = 'Amend Assessment Elements';
$string['amendtitle'] = 'Amend Title';
$string['assess'] = 'Assess';
$string['assessedon'] = 'Assessed on $a';
$string['assessment'] = 'Assessment';
$string['assessmentby'] = 'Assessment by $a';
$string['assessmentgrade'] = 'Assessment Grade: $a';
$string['assessmentnotyetagreed'] = 'Assessment not yet agreed';
$string['assessmentofthissubmission'] = 'Assessment of this submission';
$string['assessments'] = 'Assessments';
$string['assessmentsareok'] = 'Assessments are OK';
$string['assessmentsby'] = 'Assessments by $a';
$string['assessmentsdone'] = 'Assessments Done';
$string['assessmentsmustbeagreed'] = 'Assessments must be agreed';
$string['assessmentwasagreedon'] = 'Assessment was agreed on $a';
$string['assessor'] = 'Assessor';
$string['assessthissubmission'] = 'Assess this submission';
$string['assignmentnotinthecorrectphase'] = 'Assignment not in the Correct Phase';
$string['authorofsubmission'] = 'Author of Submission';
$string['awaitinggradingbyteacher'] = 'Awaiting Grading by $a';
$string['beforedeadline'] = 'Before Deadline: $a';
$string['calculationoffinalgrades'] = 'Calculation of Final Grades';
$string['closeassignment'] = 'Close Assignment';
$string['comment'] = 'Comment';
$string['commentby'] = 'Comment by';
$string['confirmdeletionofthisitem'] = 'Confirm Deletion of this $a';
$string['correct'] = 'Correct';
$string['criterion'] = 'Criterion';
$string['deadline'] = 'Deadline';
$string['deadlineis'] = 'The Deadline is $a';
$string['delete'] = 'Delete';
$string['deleting'] = 'Deleting';
$string['description'] = 'Description';
$string['detailsofassessment'] = 'Details of Assessment';
$string['disagreewiththisassessment'] = 'Disagree with this Assessment';
$string['displayoffinalgrades'] = 'Display of Final Grades';
$string['dontshowgrades'] = 'Don\'t Show Grades';
$string['edit'] = 'Edit';
$string['editacomment'] = 'Edit a Comment';
$string['editingassessmentelements'] = 'Editing Assessment Elements';
$string['element'] = 'Element';
$string['elementweight'] = 'Element Weight';
$string['errorbanded'] = 'Error Banded';
$string['excellent'] = 'Excellent';
$string['feedbackgoeshere'] = 'Feedback goes here';
$string['generalcomment'] = 'General comment';
$string['good'] = 'Good';
$string['grade'] = 'Grade';
$string['gradeassessment'] = 'Grade Assessment';
$string['graded'] = 'Graded';
$string['gradedbyteacher'] = 'Graded by $a';
$string['gradeforassessments'] = 'Grade for Assessments';
$string['gradeforbias'] = 'Grade for Bias';
$string['gradeforreliability'] = 'Grade for Reliability';
$string['gradeforstudentsassessment'] = 'Grade for Student\'s Assessment';
$string['gradeofsubmission'] = 'Grade of Submission: $a';
$string['gradingstrategy'] = 'Grading Strategy';
$string['hidegradesbeforeagreement'] = 'Hide Grades before Agreement';
$string['includeteachersgrade'] = 'Include Teacher\'s Grade';
$string['incorrect'] = 'Incorrect';
$string['leaguetable'] = 'League Table of Submitted Work';
$string['listassessments'] = 'List Assessments';
$string['listofallsubmissions'] = 'List of all Submissions';
$string['liststudentsassessments'] = 'List Student\'s Assessments';
$string['mail1'] = 'Your assignment \'$a\' has been assessed by';
$string['mail2'] = 'The comments and grade can be seen in the Workshop Assignment \'$a\'';
$string['mail3'] = 'You can see it in your Workshop Assignment';
$string['mail4'] = 'A comment has been added to the assignment \'$a\' by';
$string['mail5'] = 'The new comment can be seen in the Workshop Assignment \'$a\'';
$string['mail6'] = 'Your assessment of the assignment \'$a\' has by reviewed';
$string['mail7'] = 'The comments given by the $a can be seen in the Workshop Assignment ';
$string['managingassignment'] = 'Managing Assignment';
$string['maximumsize'] = 'Maximum Size';
$string['modulename'] = 'ѐ';
$string['modulenameplural'] = 'Workshops';
$string['movingtophase'] = 'Moving to Phase $a';
$string['newassessments'] = 'New Assessments';
$string['newgradings'] = 'New Gradings';
$string['newsubmissions'] = 'New Submissions';
$string['noassessmentsdone'] = 'No Assessments Done';
$string['nosubmissionsavailableforassessment'] = 'No Submissions available for assessment';
$string['notavailable'] = 'Not Available';
$string['noteonassessmentelements'] = 'Note that grading is broken down into a number of \'Assessment Elements\'.<BR>
	This makes the grading easier and more consistent. As teacher you must add these <BR>
	Elements before making the assignment available to students. This is done by<BR>
	clicking on the assignment in the course, if no elements are present you will be asked<BR>
	to add them. You can change the number of elements using the Edit Assignment screen,<BR>
	the elements themselves can be amended from the \"Managing Assessment\" screen. ';
$string['notgraded'] = 'Not Graded';
$string['notitlegiven'] = 'No Title Given';
$string['numberofassessmentelements'] = 'Number of Comments, Assessment Elements, Grade Bands, Criterion Statments or Categories in a Rubric';
$string['numberofassessments'] = 'Number of Assessments';
$string['numberofassessmentsofstudentsubmissions'] = 'Number of Assessments of Student Submissions';
$string['numberofassessmentsofteachersexamples'] = 'Number of Assessments of Examples from Teacher';
$string['on'] = 'on $a';
$string['openassignment'] = 'Open Assignment';
$string['optionforpeergrade'] = 'Option for Peer Grade';
$string['overallgrade'] = 'Overall Grade';
$string['overallpeergrade'] = 'Overall Peer Grade: $a';
$string['overallteachergrade'] = 'Overall Teacher Grade: $a';
$string['ownwork'] = 'Own Work';
$string['phase'] = 'Phase';
$string['phase1'] = 'Set Up Assignment';
$string['phase2'] = 'Allow $a Submissions and Assessments';
$string['phase3'] = 'Calculation of Final Grades';
$string['phase4'] = 'Show Final Grades';
$string['pleaseassesstheseexamplesfromtheteacher'] = 'Please assess these Examples from the $a';
$string['pleaseassessthesestudentsubmissions'] = 'Please assess these $a Submissions';
$string['pleaseassessyoursubmissions'] = 'Please assess your Submission(s)';
$string['poor'] = 'Poor';
$string['present'] = 'Present';
$string['reassess'] = 'Re-assess';
$string['reply'] = 'Reply';
$string['returnto'] = 'Return to';
$string['returntosubmissionpage'] = 'Return to Submission Page';
$string['rubric'] = 'Rubric';
$string['savedok'] = 'Saved OK';
$string['savemyassessment'] = 'Save my Assessment';
$string['savemycomment'] = 'Save my Comment';
$string['savemygrading'] = 'Save my Grading';
$string['scale10'] = 'Score out of 10';
$string['scale100'] = 'Score out of 100';
$string['scale20'] = 'Score out of 20';
$string['scalecorrect'] = '2 point Correct/Incorrect scale';
$string['scaleexcellent4'] = '4 point Excellent/Very Poor scale';
$string['scaleexcellent5'] = '5 point Excellent/Very Poor scale';
$string['scaleexcellent7'] = '7 point Excellent/Very Poor scale';
$string['scalegood3'] = '3 point Good/Poor scale';
$string['scalepresent'] = '2 point Present/Absent scale';
$string['scaleyes'] = '2 point Yes/No scale';
$string['select'] = 'Select';
$string['selfassessment'] = 'Self Assessment';
$string['showgrades'] = 'Show Grades';
$string['specimenassessmentform'] = 'Specimen Assessment Form';
$string['studentassessments'] = '$a Assessments';
$string['studentgrades'] = '$a Grades';
$string['studentsubmissions'] = '$a Submissions';
$string['studentsubmissionsforassessment'] = '$a Student Submissions for Assessment';
$string['submission'] = 'Submission';
$string['submissions'] = 'Submissions';
$string['submitassignment'] = 'Submit Assignment';
$string['submitexampleassignment'] = 'Submit Example Assignment';
$string['submitted'] = 'Submitted';
$string['submittedby'] = 'Submitted by';
$string['suggestedgrade'] = 'Suggested Grade';
$string['teacherassessments'] = '$a Assessments';
$string['teacherscomment'] = 'Teacher\'s Comment';
$string['teachersgrade'] = 'Teacher\'s Grade';
$string['teachersubmissionsforassessment'] = '$a Teacher Submissions for Assessment';
$string['thegradeis'] = 'The Grade is $a';
$string['thereisfeedbackfromtheteacher'] = 'There is feadback from the $a';
$string['theseasessmentsaregradedbytheteacher'] = 'These Assessments are graded by the $a';
$string['timeassessed'] = 'Time Assessed';
$string['title'] = 'Title';
$string['typeofscale'] = 'Type of Scale';
$string['ungradedassessmentsofstudentsubmissions'] = '$a Ungraded Assessments of Student Submissions';
$string['ungradedassessmentsofteachersubmissions'] = '$a Ungraded Assessments of Teacher Submissions';
$string['verypoor'] = 'Very Poor';
$string['view'] = 'View';
$string['viewassessmentofteacher'] = 'View Assessment of $a';
$string['viewotherassessments'] = 'View other Assessments';
$string['warningonamendingelements'] = 'WARNING: There are submitted assessments. <BR>Do NOT change the number
 of elements, the scale types or the element weights.';
$string['weightederrorcount'] = 'Weighted Error Count: $a';
$string['weightforbias'] = 'Weight for Bias';
$string['weightforgradingofassessments'] = 'Weight for Grading of Assessments';
$string['weightforpeerassessments'] = 'Weight for Peer Assessments';
$string['weightforreliability'] = 'Weight for Reliability';
$string['weightforteacherassessments'] = 'Weight for $a Assessments';
$string['weights'] = 'Weights';
$string['weightsusedforfinalgrade'] = 'Weights used for Final Grade';
$string['weightsusedforsubmissions'] = 'Weights used for Submissions';
$string['yourassessments'] = 'Your Assessments';
$string['yourfeedbackgoeshere'] = 'Your Feedback goes Here';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/fa/workshop.php <==
<?PHP // $Id$ 
      // workshop.php - created with Moodle 1.3 Beta + (2004051600)


$string['absent'] = 'Absent';
$string['accumulative'] = 'Accumulative';
$string['action'] = 'Action';
$string['addacomment'] = 'Add a Comment';
$string['afterdeadline'] = 'After Deadline: $a';
$string['agreetothisassessment'] = 'Agree to this Assessment';
$string['allgradeshaveamaximumof'] = 'All Grades have a Maximum of: $a';
$string['allowresubmit'] = 'Allow Resubmissions';
$string['alreadyinphase'] = 'Already in Phase $a';
$string['amendassessmentelements'] = 'Amend Assessment Elements';
$string['amendtitle'] = 'Amend Title';
$string['assess'] = 'Assess';
$string['assessedon'] = 'Assessed on $a';
$string['assessment'] = 'Assessment';
$string['assessmentby'] = 'Assessment by $a';
$string['assessmentgrade'] = 'Assessment Grade: $a';
$string['assessmentnotyetagreed'] = 'Assessment not yet agreed';
$string['assessmentofthissubmission'] = 'Assessment of this submission';
$string['assessments'] = 'Assessments';
$string['assessmentsareok'] = 'Assessments are OK';
$string['assessmentsby'] = 'Assessments by $a';
$string['assessmentsdone'] = 'Assessments Done';
$string['assessmentsmustbeagreed'] = 'Assessments must be agreed';
$string['assessmentwasagreedon'] = 'Assessment was agreed on $a';
$string['assessor'] = 'Assessor';
$string['assessthissubmission'] = 'Assess this submission';
$string['assignmentnotinthecorrectphase'] = 'Assignment not in the Correct Phase';
$string['authorofsubmission'] = 'Author of Submission';
$string['awaitinggradingbyteacher'] = 'Awaiting Grading by $a';
$string['beforedeadline'] = 'Before Deadline: $a';
$string['calculationoffinalgrades'] = 'Calculation of Final Grades';
$string['closeassignment'] = 'Close Assignment';
$string['comment'] = 'Comment';
$string['commentby'] = 'Comment by';
$string['confirmdeletionofthisitem'] = 'Confirm Deletion of this $a';
$string['correct'] = 'Correct';
$string['criterion'] = 'Criterion';
$string['deadline'] = 'Deadline';
$string['deadlineis'] = 'The Deadline is $a';
$string['delete'] = 'Delete';
$string['deleting'] = 'Deleting';
$string['description'] = 'Description';
$string['detailsofassessment'] = 'Details of Assessment';
$string['disagreewiththisassessment'] = 'Disagree with this Assessment';
$string['displayoffinalgrades'] = 'Display of Final Grades';
$string['dontshowgrades'] = 'Don\'t Show Grades';
$string['edit'] = 'Edit';
$string['editacomment'] = 'Edit a Comment';
$string['editingassessmentelements'] = 'Editing Assessment Elements';
$string['element'] = 'Element';
$string['elementweight'] = 'Element Weight';
$string['errorbanded'] = 'Error Banded';
$string['excellent'] = 'Excellent';
$string['feedbackgoeshere'] = 'Feedback goes here';
$string['generalcomment'] = 'General comment';
$string['good'] = 'Good';
$string['grade'] = 'Grade';
$string['gradeassessment'] = 'Grade Assessment';
$string['graded'] = 'Graded';
$string['gradedbyteacher'] = 'Graded by $a';
$string['gradeforassessments'] = 'Grade for Assessments';
$string['gradeforbias'] = 'Grade for Bias';
$string['gradeforreliability'] = 'Grade for Reliability';
$string['gradeforstudentsassessment'] = 'Grade for Student\'s Assessment';
$string['gradeofsubmission'] = 'Grade of Submission: $a';
$string['gradingstrategy'] = 'Grading Strategy';
$string['hidegradesbeforeagreement'] = 'Hide Grades before Agreement';
$string['includeteachersgrade'] = 'Include Teacher\'s Grade';
$string['incorrect'] = 'Incorrect';
$string['leaguetable'] = 'League Table of Submitted Work';
$string['listassessments'] = 'List Assessments';
$string['listofallsubmissions'] = 'List of all Submissions';
$string['liststudentsassessments'] = 'List Student\'s Assessments';
$string['mail1'] = 'Your assignment \'$a\' has been assessed by';
$string['mail2'] = 'The comments and grade can be seen in the Workshop Assignment \'$a\'';
$string['mail3'] = 'You can see it in your Workshop Assignment';
$string['mail4'] = 'A comment has been added to the assignment \'$a\' by';
$string['mail5'] = 'The new comment can be seen in the Workshop Assignment \'$a\'';
$string['mail6'] = 'Your assessment of the assignment \'$a\' has by reviewed';
$string['mail7'] = 'The comments given by the $a can be seen in the Workshop Assignment ';
$string['managingassignment'] = 'Managing Assignment';
$string['maximumsize'] = 'Maximum Size';
$string['modulename'] = 'ѐ';
$string['modulenameplural'] = 'Workshops';
$string['movingtophase'] = 'Moving to Phase $a';
$string['newassessments'] = 'New Assessments';
$string['newgradings'] = 'New Gradings';
$string['newsubmissions'] = 'New Submissions';
$string['noassessmentsdone'] = 'No Assessments Done';
$string['nosubmissionsavailableforassessment'] = 'No Submissions available for assessment';
$string['notavailable'] = 'Not Available';
$string['noteonassessmentelements'] = 'Note that grading is broken down into a number of \'Assessment Elements\'.<br />
	This makes the grading easier and more consistent. As teacher you must add these <br />
	Elements before making the assignment available to students. This is done by<br />
	clicking on the assignment in the course, if no elements are present you will be asked<br />
	to add them. You can change the number of elements using the Edit Assignment screen,<br />
	the elements themselves can be amended from the \"Managing Assessment\" screen. ';
$string['notgraded'] = 'Not Graded';
$string['notitlegiven'] = 'No Title Given';
$string['numberofassessmentelements'] = 'Number of Comments, Assessment Elements, Grade Bands, Criterion Statments or Categories in a Rubric';
$string['numberofassessments'] = 'Number of Assessments';
$string['numberofassessmentsofstudentsubmissions'] = 'Number of Assessments of Student Submissions';
$string['numberofassessmentsofteachersexamples'] = 'Number of Assessments of Examples from Teacher';
$string['on'] = 'on $a';
$string['openassignment'] = 'Open Assignment';
$string['optionforpeergrade'] = 'Option for Peer Grade';
$string['overallgrade'] = 'Overall Grade';
$string['overallpeergrade'] = 'Overall Peer Grade: $a';
$string['overallteachergrade'] = 'Overall Teacher Grade: $a';
$string['ownwork'] = 'Own Work';
$string['phase'] = 'Phase';
$string['phase1'] = 'Set Up Assignment';
$string['phase2'] = 'Allow $a Submissions and Assessments';
$string['phase3'] = 'Calculation of Final Grades';
$string['phase4'] = 'Show Final Grades';
$string['pleaseassesstheseexamplesfromtheteacher'] = 'Please assess these Examples from the $a';
$string['pleaseassessthesestudentsubmissions'] = 'Please assess these $a Submissions';
$string['pleaseassessyoursubmissions'] = 'Please assess your Submission(s)';
$string['poor'] = 'Poor';
$string['present'] = 'Present';
$string['reassess'] = 'Re-assess';
$string['reply'] = 'Reply';
$string['returnto'] = 'Return to';
$string['returntosubmissionpage'] = 'Return to Submission Page';
$string['rubric'] = 'Rubric';
$string['savedok'] = 'Saved OK';
$string['savemyassessment'] = 'Save my Assessment';
$string['savemycomment'] = 'Save my Comment';
$string['savemygrading'] = 'Save my Grading';
$string['scale10'] = 'Score out of 10';
$string['scale100'] = 'Score out of 100';
$string['scale20'] = 'Score out of 20';
$string['scalecorrect'] = '2 point Correct/Incorrect scale';
$string['scaleexcellent4'] = '4 point Excellent/Very Poor scale';
$string['scaleexcellent5'] = '5 point Excellent/Very Poor scale';
$string['scaleexcellent7'] = '7 point Excellent/Very Poor scale';
$string['scalegood3'] = '3 point Good/Poor scale';
$string['scalepresent'] = '2 point Present/Absent scale';
$string['scaleyes'] = '2 point Yes/No scale';
$string['select'] = 'Select';
$string['selfassessment'] = 'Self Assessment';
$string['showgrades'] = 'Show Grades';
$string['specimenassessmentform'] = 'Specimen Assessment Form';
$string['studentassessments'] = '$a Assessments';
$string['studentgrades'] = '$a Grades';
$string['studentsubmissions'] = '$a Submissions';
$string['studentsubmissionsforassessment'] = '$a Student Submissions for Assessment';
$string['submission'] = 'Submission';
$string['submissions'] = 'Submissions';
$string['submitassignment'] = 'Submit Assignment';
$string['submitexampleassignment'] = 'Submit Example Assignment';
$string['submitted'] = 'Submitted';
$string['submittedby'] = 'Submitted by';
$string['suggestedgrade'] = 'Suggested Grade';
$string['teacherassessments'] = '$a Assessments';
$string['teacherscomment'] = 'Teacher\'s Comment';
$string['teachersgrade'] = 'Teacher\'s Grade';
$string['teachersubmissionsforassessment'] = '$a Teacher Submissions for Assessment';
$string['thegradeis'] = 'The Grade is $a';
$string['thereisfeedbackfromtheteacher'] = 'There is feadback from the $a';
$string['theseasessmentsaregradedbytheteacher'] = 'These Assessments are graded by the $a';
$string['timeassessed'] = 'Time Assessed';
$string['title'] = 'Title';
$string['typeofscale'] = 'Type of Scale';
$string['ungradedassessmentsofstudentsubmissions'] = '$a Ungraded Assessments of Student Submissions';
$string['ungradedassessmentsofteachersubmissions'] = '$a Ungraded Assessments of Teacher Submissions';
$string['verypoor'] = 'Very Poor';
$string['view'] = 'View';
$string['viewassessmentofteacher'] = 'View Assessment of $a';
$string['viewotherassessments'] = 'View other Assessments';
$string['warningonamendingelements'] = 'WARNING: There are submitted assessments. <br />Do NOT change the number
 of elements, the scale types or the element weights.';
$string['weightederrorcount'] = 'Weighted Error Count: $a';
$string['weightforbias'] = 'Weight for Bias';
$string['weightforgradingofassessments'] = 'Weight for Grading of Assessments';
$string['weightforpeerassessments'] = 'Weight for Peer Assessments';
$string['weightforreliability'] = 'Weight for Reliability';
$string['weightforteacherassessments'] = 'Weight for $a Assessments';
$string['weights'] = 'Weights';
$string['weightsusedforfinalgrade'] = 'Weights used for Final Grade';
$string['weightsusedforsubmissions'] = 'Weights used for Submissions';
$string['yourassessments'] = 'Your Assessments';
$string['yourfeedbackgoeshere'] = 'Your Feedback goes Here';

?>
